@@ -83,13 +83,8 @@ class PostDetailView(MetaSidebar, DetailView):
     def get_context_data(self, **kwargs):
         context = super(PostDetailView, self).get_context_data(**kwargs)
         comments = mymodels.Comments.objects.filter(thread_id=self.obj.thread_id)
-        try:
-            postimages = self.obj.photo.all()
-        except:
-            postimages = False
         context.update({
             'title': self.obj.title,
-            'post_images': postimages,
             'comments': comments,
         })
         return context
